translate.storage.symbian.ParseState

Package translate :: Package storage :: Module symbian :: Class ParseState |
[hide private]
[frames] | no frames]

# Class ParseState

source code

Instance Methods | [hide private]
__init__(self, f, charset, read_hook=<function identity at 0x849072c>) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
read_line(self) | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, f, charset, read_hook=<function identity at 0x849072c>) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)